.. _pydl.pydlspec2d:

============================================
SDSS Spectroscopic Data  (`pydl.pydlspec2d`)
============================================

Introduction
------------

This is a placeholder for pydlspec2d documentation.

.. automodapi:: pydl.pydlspec2d
   :no-inheritance-diagram:
